## 为什么要使用spydy？
---

目前虽然有很多的开源的爬虫框架和工具， 但是它们大多无法同时兼顾**用户友好**以及**良好性能**这两个特性。  
所以对于为什么要使用spydy这个问题， 简而言之， Spydy可以帮助使用者以最快的速度以及更为直观的方式， 开发和部署高性能的网络爬虫。



## 安装spydy
---

使用pip进行安装：

```
$ pip install spydy
```

## 源码位置
github项目地址: [spydy](https://github.com/superjcd/spydy)